@@ -11,7 +11,8 @@ class DataFramesNotEqualError(Exception):
    pass
 
 
-def assert_df_equality(df1, df2, ignore_nullable=False, transforms=None, allow_nan_equality=False, ignore_column_order=False, ignore_row_order=False):
+def assert_df_equality(df1, df2, ignore_nullable=False, transforms=None, allow_nan_equality=False,
+                       ignore_column_order=False, ignore_row_order=False, ignore_schema=False):
     if transforms is None:
         transforms = []
     if ignore_column_order:
@@ -20,7 +21,8 @@ def assert_df_equality(df1, df2, ignore_nullable=False, transforms=None, allow_n
         transforms.append(lambda df: df.sort(df.columns))
     df1 = reduce(lambda acc, fn: fn(acc), transforms, df1)
     df2 = reduce(lambda acc, fn: fn(acc), transforms, df2)
-    assert_schema_equality(df1.schema, df2.schema, ignore_nullable)
+    if not ignore_schema:
+        assert_schema_equality(df1.schema, df2.schema, ignore_nullable)
     if allow_nan_equality:
         assert_generic_rows_equality(df1, df2, are_rows_equal_enhanced, [True])
     else:
